/* eslint-env jest */
const ModECS = require('../index')

describe('ModECS', () => {

    let engine

    beforeEach(() => {
        engine = ModECS()
        engine.registerComponent('POSITION', {x:0,y:0})
    })

    it('should create a component', () => {
        expect(() => engine.createComponent('POSITION')).not.toThrow()
    })

    it('should create a component with values', () => {
        engine.compile()

        const position = engine.createComponent('POSITION', {x:2,y:2})

        expect(position.x).toEqual(2)
        expect(position.y).toEqual(2)
    })

    it('should create an entity', () => {
        const id = engine.createEntity()
        expect(id).toBe(0)
    })

    it('should add registered component to an entity', () => {
        const id = engine.createEntity()
        expect(() => engine.addComponent(id, 'POSITION')).not.toThrow()
    })
})

describe('Scenario 1', () => {
    const engine = ModECS()

    engine.registerComponent('POSITION', {x:0,y:0})
    engine.registerComponent('TARGET', {x:0,y:0})


    engine.registerSystem(
        'Move',
        ['POSITION','TARGET'],
        () => (position, target, id) => {
            position.x += target.x
            position.y += target.y
        }
    )

    // engine.compile()

    const e1 = engine.createEntity()
    engine.addComponent(e1, 'POSITION')
    engine.addComponent(e1, 'TARGET')

    const e2 = engine.createEntity()
    engine.addComponent(e2, 'POSITION')
    engine.addComponent(e2, 'TARGET')


    it('should', () => {
        const moveView = engine.createView('POSITION', 'TARGET')
        expect(moveView).toHaveProperty('TARGET')

        engine.removeComponent(e1, 'POSITION', true)

    })

})